==> SquirroClient-2.6.1.tar.gz: SquirroClient-2.6.1/squirro_client/topic/subscriptions.py <==
import json


class SubscriptionsMixin(object):

    def get_object_subscriptions(self, project_id, object_id, user_id=None,
                                 filter_deleted=None):
        """Get all subscriptions for the provided object.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param user_id: User identifier.
        :param filter_deleted: If `True` returns only non-deleted
            subscriptions.
        :returns: A list which contains subscriptions.

        Example::

            >>> client.get_object_subscriptions('2sic33jZTi-ifflvQAVcfw',
            ...                                 '2TBYtWgRRIa23h1rEveI3g')
            [
                {
                    u'config': {
                        u'market': u'de-CH',
                        u'query': u'squirro',
                        u'vertical': u'News',
                    },
                    u'deleted': False,
                    u'id': u'hw8j7LUBRM28-jAellgQdA',
                    u'link': u'http://bing.com/news/search?q=squirro',
                    u'modified_at': u'2012-10-09T07:54:12',
                    u'provider': u'bing',
                    u'seeder': None,
                    u'source_id': u'2VkLodDHTmiMO3rlWi2MVQ',
                    u'title': u'News Alerts for "squirro" in Switzerland',
                    u'workflow': {
                        u'name': u'Default Workflow',
                        u'project_default': True,
                        u'id': u'kAvdogQOQvGHijqcIPi_WA',
                        u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'
                    }
                }
            ]
        """

        url = ('%(ep)s/%(version)s/%(tenant)s'
               '/projects/%(project_id)s'
               '/objects/%(object_id)s/subscriptions')
        url = url % {
            'ep': self.topic_api_url, 'version': self.version,
            'tenant': self.tenant, 'project_id': project_id,
            'object_id': object_id}

        # build params
        params = {}
        if user_id is not None:
            params['user_id'] = user_id
        if filter_deleted is not None:
            params['filter_deleted'] = filter_deleted

        res = self._perform_request('get', url, params=params)
        return self._process_response(res)

    def get_subscription(self, project_id, object_id, subscription_id):
        """Get subscription details.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.
        :returns: A dictionary which contains the subscription.

        Example::

            >>> client.get_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw', '2TBYtWgRRIa23h1rEveI3g',
            ...     'hw8j7LUBRM28-jAellgQdA')
            {
                u'config': {
                    u'market': u'de-CH',
                    u'query': u'squirro',
                    u'vertical': u'News',
                },
                u'deleted': False,
                u'id': u'hw8j7LUBRM28-jAellgQdA',
                u'link': u'http://bing.com/news/search?q=squirro',
                u'modified_at': u'2012-10-09T07:54:12',
                u'provider': u'bing',
                u'seeder': None,
                u'source_id': u'2VkLodDHTmiMO3rlWi2MVQ',
                u'title': u'News Alerts for "squirro" in Switzerland',
                u'processed': True,
                u'paused': False,
                u'workflow': {
                    u'name': u'Default Workflow',
                    u'project_default': True,
                    u'id': u'kAvdogQOQvGHijqcIPi_WA',
                    u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'
                }
            }
        """

        url = ('%(ep)s/%(version)s/%(tenant)s'
               '/projects/%(project_id)s'
               '/objects/%(object_id)s/subscriptions/%(subscription_id)s')
        url = url % {
            'ep': self.topic_api_url, 'version': self.version,
            'tenant': self.tenant, 'project_id': project_id,
            'object_id': object_id,
            'subscription_id': subscription_id}

        res = self._perform_request('get', url)
        return self._process_response(res)

    def new_subscription(self, project_id, object_id, provider, config,
                         user_id=None, seeder=None, private=None,
                         workflow_id=None, subscription_id=None):
        """Create a new subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param provider: Provider name.
        :param config: Provider configuration dictionary.
        :param workflow_id: Optional id of the pipeline workflow to apply to
            the data of this subscription. If not specified, then the default
            workflow of the project with `project_id` will be applied.
        :param user_id: User identifier.
        :param seeder: Seeder which manages the subscription.
        :param private: Hints that the contents for this subscriptions should
            be treated as private.
        :param subscription_id: Optional string parameter to create the
            subscription with the provided id. The length of the parameter must
            be 22 characters. Useful when exporting and importing projects
            across multiple Squirro servers.
        :returns: A dictionary which contains the new subscription.

        Example::

            >>> client.new_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw', '2TBYtWgRRIa23h1rEveI3g',
            ...     'feed', {'url': 'http://blog.squirro.com/rss'})
            {u'config': {u'url': u'http://blog.squirro.com/rss'},
             u'deleted': False,
             u'id': u'oTvI6rlaRmKvmYCfCvLwpw',
             u'link': u'http://blog.squirro.com/rss',
             u'modified_at': u'2012-10-12T09:32:09',
             u'provider': u'feed',
             u'seeder': u'team',
             u'source_id': u'D3Q8AiPoTg69bIkqFhe3Bw',
             u'title': u'Squirro',
             u'processed': False,
             u'paused': False,
             u'workflow': {
                u'name': u'Default Workflow',
                u'project_default': True,
                u'id': u'kAvdogQOQvGHijqcIPi_WA',
                u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'}
            }
        """

        url = ('%(ep)s/%(version)s/%(tenant)s'
               '/projects/%(project_id)s'
               '/objects/%(object_id)s/subscriptions')
        url = url % {
            'ep': self.topic_api_url, 'version': self.version,
            'tenant': self.tenant, 'project_id': project_id,
            'object_id': object_id}

        # inject token for dataloader provider
        if provider == 'dataloader':
            dataloader_options = config.get('dataloader_options', {})
            dataloader_options['token'] = self.refresh_token
            config['dataloader_options'] = dataloader_options

        # build data
        data = {
            'provider': provider, 'config': json.dumps(config)
        }
        if subscription_id is not None:
            data['subscription_id'] = subscription_id
        if workflow_id is not None:
            data['workflow_id'] = workflow_id
        if user_id is not None:
            data['user_id'] = user_id
        if seeder is not None:
            data['seeder'] = seeder
        if private is not None:
            data['private'] = private

        res = self._perform_request('post', url, data=data)
        return self._process_response(res, [200, 201])

    def modify_subscription(self, project_id, object_id, subscription_id,
                            workflow_id=None, config=None):
        """Modify an existing subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.
        :param workflow_id: Optional workflow id to change subscription to.
        :param config: Changed config of the subscription.

        :returns: A dictionary which contains the subscription.

        Example::

            >>> client.modify_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw',
            ...     '2TBYtWgRRIa23h1rEveI3g',
            ...     'oTvI6rlaRmKvmYCfCvLwpw',
            ...     config={'url': 'http://blog.squirro.com/atom'})
        """

        url = ('%(ep)s/%(version)s/%(tenant)s'
               '/projects/%(project_id)s'
               '/objects/%(object_id)s/subscriptions/%(subscription_id)s')
        url = url % {
            'ep': self.topic_api_url, 'version': self.version,
            'tenant': self.tenant, 'project_id': project_id,
            'object_id': object_id, 'subscription_id': subscription_id}

        # build data
        data = {}
        if workflow_id is not None:
            data['workflow_id'] = workflow_id
        if config is not None:
            data['config'] = json.dumps(config)

        res = self._perform_request('put', url, data=data)
        return self._process_response(res, [200])

    def delete_subscription(self, project_id, object_id, subscription_id,
                            seeder=None):
        """Delete an existing subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.
        :param seeder: Seeder that deletes the subscription.

        Example::

            >>> client.delete_subscription('2sic33jZTi-ifflvQAVcfw',
            ...                            '2TBYtWgRRIa23h1rEveI3g',
            ...                            'oTvI6rlaRmKvmYCfCvLwpw')

        """

        url = ('%(ep)s/%(version)s/%(tenant)s'
               '/projects/%(project_id)s'
               '/objects/%(object_id)s/subscriptions/%(subscription_id)s')
        url = url % {
            'ep': self.topic_api_url, 'version': self.version,
            'tenant': self.tenant, 'project_id': project_id,
            'object_id': object_id,
            'subscription_id': subscription_id}

        # build params
        params = {}
        if seeder is not None:
            params['seeder'] = seeder

        res = self._perform_request('delete', url, params=params)
        self._process_response(res, [204])

    def pause_subscription(self, project_id, object_id, subscription_id):
        """Pause a subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.

        Example::

            >>> client.pause_subscription('2sic33jZTi-ifflvQAVcfw',
            ...                           '2TBYtWgRRIa23h1rEveI3g',
            ...                           'hw8j7LUBRM28-jAellgQdA')
        """

        url = ('%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s'
               '/objects/%(object_id)s/subscriptions/%(subscription_id)s/'
               'pause')
        url = url % {
            'ep': self.topic_api_url, 'version': self.version,
            'tenant': self.tenant, 'project_id': project_id,
            'object_id': object_id,
            'subscription_id': subscription_id}

        res = self._perform_request('post', url)
        self._process_response(res, [200, 204])

    def resume_subscription(self, project_id, object_id, subscription_id):
        """Resume a paused subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.

        Example::

            >>> client.resume_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw', '2TBYtWgRRIa23h1rEveI3g',
            ...     'hw8j7LUBRM28-jAellgQdA')
        """

        url = ('%(ep)s/%(version)s/%(tenant)s'
               '/projects/%(project_id)s'
               '/objects/%(object_id)s/subscriptions/%(subscription_id)s/'
               'resume')
        url = url % {
            'ep': self.topic_api_url, 'version': self.version,
            'tenant': self.tenant, 'project_id': project_id,
            'object_id': object_id,
            'subscription_id': subscription_id}

        res = self._perform_request('post', url)
        self._process_response(res, [200, 204])

==> SquirroClient-2.6.5.tar.gz: SquirroClient-2.6.5/squirro_client/topic/subscriptions.py <==
# TODO: remove this file completely
from ..util import deprecation


class SubscriptionsMixin(object):

    def get_object_subscriptions(self, project_id, object_id, user_id=None,
                                 filter_deleted=None):
        """
        DEPRECATED: subscriptions no longer exist.

        Get all subscriptions for the provided object.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param user_id: User identifier.
        :param filter_deleted: If `True` returns only non-deleted
            subscriptions.
        :returns: A list which contains subscriptions.

        Example::

            >>> client.get_object_subscriptions('2sic33jZTi-ifflvQAVcfw',
            ...                                 '2TBYtWgRRIa23h1rEveI3g')
            [
                {
                    u'config': {
                        u'market': u'de-CH',
                        u'query': u'squirro',
                        u'vertical': u'News',
                    },
                    u'deleted': False,
                    u'id': u'hw8j7LUBRM28-jAellgQdA',
                    u'link': u'http://bing.com/news/search?q=squirro',
                    u'modified_at': u'2012-10-09T07:54:12',
                    u'provider': u'bing',
                    u'seeder': None,
                    u'source_id': u'2VkLodDHTmiMO3rlWi2MVQ',
                    u'title': u'News Alerts for "squirro" in Switzerland',
                    u'workflow': {
                        u'name': u'Default Workflow',
                        u'project_default': True,
                        u'id': u'kAvdogQOQvGHijqcIPi_WA',
                        u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'
                    }
                }
            ]
        """
        msg = "Subscriptions are deprecated and replaced with sources. " \
              "Please use `get_sources` instead."
        deprecation(msg)
        raise NotImplementedError(msg)

    def get_subscription(self, project_id, object_id, subscription_id):
        """
        DEPRECATED: subscriptions no longer exist.

        Get subscription details.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.
        :returns: A dictionary which contains the subscription.

        Example::

            >>> client.get_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw', '2TBYtWgRRIa23h1rEveI3g',
            ...     'hw8j7LUBRM28-jAellgQdA')
            {
                u'config': {
                    u'market': u'de-CH',
                    u'query': u'squirro',
                    u'vertical': u'News',
                },
                u'deleted': False,
                u'id': u'hw8j7LUBRM28-jAellgQdA',
                u'link': u'http://bing.com/news/search?q=squirro',
                u'modified_at': u'2012-10-09T07:54:12',
                u'provider': u'bing',
                u'seeder': None,
                u'source_id': u'2VkLodDHTmiMO3rlWi2MVQ',
                u'title': u'News Alerts for "squirro" in Switzerland',
                u'processed': True,
                u'paused': False,
                u'workflow': {
                    u'name': u'Default Workflow',
                    u'project_default': True,
                    u'id': u'kAvdogQOQvGHijqcIPi_WA',
                    u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'
                }
            }
        """

        msg = "Subscriptions are deprecated and replaced with sources. " \
              "Please use `get_source` instead."
        deprecation(msg)
        raise NotImplementedError(msg)

    def new_subscription(self, project_id, object_id, provider, config,
                         user_id=None, seeder=None, private=None,
                         workflow_id=None, subscription_id=None):
        """
        DEPRECATED: subscriptions no longer exist.

        Create a new subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param provider: Provider name.
        :param config: Provider configuration dictionary.
        :param workflow_id: Optional id of the pipeline workflow to apply to
            the data of this subscription. If not specified, then the default
            workflow of the project with `project_id` will be applied.
        :param user_id: User identifier.
        :param seeder: Seeder which manages the subscription.
        :param private: Hints that the contents for this subscriptions should
            be treated as private.
        :param subscription_id: Optional string parameter to create the
            subscription with the provided id. The length of the parameter must
            be 22 characters. Useful when exporting and importing projects
            across multiple Squirro servers.
        :returns: A dictionary which contains the new subscription.

        Example::

            >>> client.new_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw', '2TBYtWgRRIa23h1rEveI3g',
            ...     'feed', {'url': 'http://blog.squirro.com/rss'})
            {u'config': {u'url': u'http://blog.squirro.com/rss'},
             u'deleted': False,
             u'id': u'oTvI6rlaRmKvmYCfCvLwpw',
             u'link': u'http://blog.squirro.com/rss',
             u'modified_at': u'2012-10-12T09:32:09',
             u'provider': u'feed',
             u'seeder': u'team',
             u'source_id': u'D3Q8AiPoTg69bIkqFhe3Bw',
             u'title': u'Squirro',
             u'processed': False,
             u'paused': False,
             u'workflow': {
                u'name': u'Default Workflow',
                u'project_default': True,
                u'id': u'kAvdogQOQvGHijqcIPi_WA',
                u'project_id': u'FzbcEMMNTBeQcG2wnwnxLQ'}
            }
        """

        msg = "Subscriptions are deprecated and replaced with sources. " \
              "Please use `new_sources` instead."
        deprecation(msg)
        raise NotImplementedError(msg)

    def modify_subscription(self, project_id, object_id, subscription_id,
                            workflow_id=None, config=None):
        """
        DEPRECATED: subscriptions no longer exist.

        Modify an existing subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.
        :param workflow_id: Optional workflow id to change subscription to.
        :param config: Changed config of the subscription.

        :returns: A dictionary which contains the subscription.

        Example::

            >>> client.modify_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw',
            ...     '2TBYtWgRRIa23h1rEveI3g',
            ...     'oTvI6rlaRmKvmYCfCvLwpw',
            ...     config={'url': 'http://blog.squirro.com/atom'})
        """

        msg = "Subscriptions are deprecated and replaced with sources. " \
              "Please use `modify_sources` instead."
        deprecation(msg)
        raise NotImplementedError(msg)

    def delete_subscription(self, project_id, object_id, subscription_id,
                            seeder=None):
        """
        DEPRECATED: subscriptions no longer exist.

        Delete an existing subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.
        :param seeder: Seeder that deletes the subscription.

        Example::

            >>> client.delete_subscription('2sic33jZTi-ifflvQAVcfw',
            ...                            '2TBYtWgRRIa23h1rEveI3g',
            ...                            'oTvI6rlaRmKvmYCfCvLwpw')

        """

        msg = "Subscriptions are deprecated and replaced with sources. " \
              "Please use `delete_sources` instead."
        deprecation(msg)
        raise NotImplementedError(msg)

    def pause_subscription(self, project_id, object_id, subscription_id):
        """
        DEPRECATED: subscriptions no longer exist.

        Pause a subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.

        Example::

            >>> client.pause_subscription('2sic33jZTi-ifflvQAVcfw',
            ...                           '2TBYtWgRRIa23h1rEveI3g',
            ...                           'hw8j7LUBRM28-jAellgQdA')
        """

        msg = "Subscriptions are deprecated and replaced with sources. " \
              "Please use `pause_sources` instead."
        deprecation(msg)
        raise NotImplementedError(msg)

    def resume_subscription(self, project_id, object_id, subscription_id):
        """
        DEPRECATED: subscriptions no longer exist.

        Resume a paused subscription.

        :param project_id: Project identifier.
        :param object_id: Object identifier.
        :param subscription_id: Subscription identifier.

        Example::

            >>> client.resume_subscription(
            ...     '2sic33jZTi-ifflvQAVcfw', '2TBYtWgRRIa23h1rEveI3g',
            ...     'hw8j7LUBRM28-jAellgQdA')
        """

        msg = "Subscriptions are deprecated and replaced with sources. " \
              "Please use `resume_sources` instead."
        deprecation(msg)
        raise NotImplementedError(msg)
